@@ -128,6 +128,8 @@ typedef struct capture_info capture_info_t;
 struct capture_config {
     //! Calls capture limit. 0 for disabling
     size_t limit;
+    //! Set size of pcap buffer
+    size_t pcap_buffer_size;
     //! Also capture RTP packets
     bool rtp_capture;
     //! Rotate capturad dialogs when limit have reached
@@ -189,9 +191,10 @@ struct capture_info
  * @param limit Numbers of calls >0
  * @param rtp_catpure Enable rtp capture
  * @param rotate Enable capture rotation
+ * @param set size of pcap buffer
  */
 void
-capture_init(size_t limit, bool rtp_capture, bool rotate);
+capture_init(size_t limit, bool rtp_capture, bool rotate, size_t pcap_buffer_size);
 
 /**
  * @brief Deinitialize capture data
