@@ -610,7 +610,6 @@ capture_eep_receive_v3()
 #endif
     hep_chunk_t payload_chunk;
     hep_chunk_t authkey_chunk;
-    hep_chunk_t uuid_chunk;
     char password[100];
     int password_len;
     unsigned char *payload = 0;
@@ -762,13 +761,13 @@ int
 capture_eep_set_server_url(const char *url)
 {
     char urlstr[256];
-    char address[256], port[256];
+    char address[ADDRESSLEN + 1], port[6];
 
     memset(address, 0, sizeof(address));
     memset(port, 0, sizeof(port));
 
     strncpy(urlstr, url, sizeof(urlstr));
-    if (sscanf(urlstr, "%*[^:]:%[^:]:%s", address, port) == 2) {
+    if (sscanf(urlstr, "%*[^:]:%" STRINGIFY(ADDRESSLEN) "[^:]:%5s", address, port) == 2) {
         setting_set_value(SETTING_EEP_LISTEN, SETTING_ON);
         setting_set_value(SETTING_EEP_LISTEN_ADDR, address);
         setting_set_value(SETTING_EEP_LISTEN_PORT, port);
@@ -781,13 +780,13 @@ int
 capture_eep_set_client_url(const char *url)
 {
     char urlstr[256];
-    char address[256], port[256];
+    char address[ADDRESSLEN + 1], port[6];
 
     memset(address, 0, sizeof(address));
     memset(port, 0, sizeof(port));
 
     strncpy(urlstr, url, sizeof(urlstr));
-    if (sscanf(urlstr, "%*[^:]:%[^:]:%s", address, port) == 2) {
+    if (sscanf(urlstr, "%*[^:]:%" STRINGIFY(ADDRESSLEN) "[^:]:%5s", address, port) == 2) {
         setting_set_value(SETTING_EEP_SEND, SETTING_ON);
         setting_set_value(SETTING_EEP_SEND_ADDR, address);
         setting_set_value(SETTING_EEP_SEND_PORT, port);
