@@ -46,6 +46,7 @@ setting_t settings[SETTING_COUNT] = {
     { SETTING_CAPTURE_LIMIT,      "capture.limit",      SETTING_FMT_NUMBER,  "20000",     NULL },
     { SETTING_CAPTURE_DEVICE,     "capture.device",     SETTING_FMT_STRING,  "any",       NULL },
     { SETTING_CAPTURE_OUTFILE,    "capture.outfile",    SETTING_FMT_STRING,  "",          NULL },
+    { SETTING_CAPTURE_BUFFER,     "capture.buffer",     SETTING_FMT_NUMBER,  "2",         NULL },
 #if defined(WITH_GNUTLS) || defined(WITH_OPENSSL)
     { SETTING_CAPTURE_KEYFILE,    "capture.keyfile",    SETTING_FMT_STRING,  "",          NULL },
     { SETTING_CAPTURE_TLSSERVER,  "capture.tlsserver",  SETTING_FMT_STRING,  "",          NULL },
@@ -58,6 +59,7 @@ setting_t settings[SETTING_COUNT] = {
     { SETTING_SIP_CALLS,          "sip.calls",          SETTING_FMT_ENUM,    SETTING_OFF, SETTING_ENUM_ONOFF },
     { SETTING_SAVEPATH,           "savepath",           SETTING_FMT_STRING,  "",          NULL },
     { SETTING_DISPLAY_ALIAS,      "displayalias",       SETTING_FMT_ENUM,    SETTING_OFF, SETTING_ENUM_ONOFF },
+    { SETTING_ALIAS_PORT,         "aliasport",          SETTING_FMT_ENUM,    SETTING_OFF, SETTING_ENUM_ONOFF },
     { SETTING_CL_SCROLLSTEP,      "cl.scrollstep",      SETTING_FMT_NUMBER,  "4",         NULL },
     { SETTING_CL_COLORATTR,       "cl.colorattr",       SETTING_FMT_ENUM,    SETTING_ON,  SETTING_ENUM_ONOFF },
     { SETTING_CL_AUTOSCROLL,      "cl.autoscroll",      SETTING_FMT_ENUM,    SETTING_OFF, SETTING_ENUM_ONOFF },
