@@ -82,6 +82,7 @@ enum setting_id {
     SETTING_CAPTURE_LIMIT,
     SETTING_CAPTURE_DEVICE,
     SETTING_CAPTURE_OUTFILE,
+    SETTING_CAPTURE_BUFFER,
 #if defined(WITH_GNUTLS) || defined(WITH_OPENSSL)
     SETTING_CAPTURE_KEYFILE,
     SETTING_CAPTURE_TLSSERVER,
@@ -94,6 +95,7 @@ enum setting_id {
     SETTING_SIP_CALLS,
     SETTING_SAVEPATH,
     SETTING_DISPLAY_ALIAS,
+    SETTING_ALIAS_PORT,
     SETTING_CL_SCROLLSTEP,
     SETTING_CL_COLORATTR,
     SETTING_CL_AUTOSCROLL,
